import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { SensorResultVO, SensorResultForm, SensorResultQuery } from '@/api/qms/sensorResult/types';

/**
 * 查询批次明细列表
 * @param query
 * @returns {*}
 */

export const listSensorResult = (query?: SensorResultQuery): AxiosPromise<SensorResultVO[]> => {
  return request({
    url: '/qms/sensorResult/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询批次明细详细
 * @param batchCode
 */
export const getSensorResult = (batchCode: string | number): AxiosPromise<SensorResultVO> => {
  return request({
    url: '/qms/sensorResult/' + batchCode,
    method: 'get'
  });
};

/**
 * 新增批次明细
 * @param data
 */
export const addSensorResult = (data: SensorResultForm) => {
  return request({
    url: '/qms/sensorResult',
    method: 'post',
    data: data
  });
};

/**
 * 修改批次明细
 * @param data
 */
export const updateSensorResult = (data: SensorResultForm) => {
  return request({
    url: '/qms/sensorResult',
    method: 'put',
    data: data
  });
};

/**
 * 删除批次明细
 * @param batchCode
 */
export const delSensorResult = (batchCode: string | number | Array<string | number>) => {
  return request({
    url: '/qms/sensorResult/' + batchCode,
    method: 'delete'
  });
};
